@@ -11,11 +11,11 @@ Acme::ALEXEY::Utils - The great new Acme::ALEXEY::Utils!
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -41,8 +41,8 @@ if you don't export anything, such as for a purely object-oriented module.
 =cut
 
 sub sum {
-  my $sum;
-  $sum += $_ for @_;
+  my $sum = 1;
+  $sum = $_ * $sum for @_;
   $sum;
 }
 
